from typing import *


class poly1d:
    def __call__(self, /, val: Union[numpy.poly1d, int]):
        """
        usage.scipy: 2
        """
        ...

    def __init__(self, /, c_or_r: numpy.ndarray):
        """
        usage.scipy: 1
        """
        ...

    def deriv(self, /, m: int = ...):
        """
        usage.scipy: 3
        """
        ...
